@@ -25,33 +25,32 @@
 # Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import os
-import sys
 import signal
+import sys
 
-from gi.repository import GObject
+from gi.repository import GLib
 
-from ubiquity import filteredcommand, i18n
-from ubiquity import misc
+from ubiquity import filteredcommand, i18n, misc, telemetry
 from ubiquity.components import install, plugininstall, partman_commit
-from ubiquity.plugin import Plugin
-import ubiquity.progressposition
 import ubiquity.frontend.base
 from ubiquity.frontend.base import BaseFrontend
+from ubiquity.plugin import Plugin
+import ubiquity.progressposition
+
 
 class Wizard(BaseFrontend):
-
     def __init__(self, distro):
         BaseFrontend.__init__(self, distro)
 
         with misc.raised_privileges():
             self.console = open('/dev/console', 'w')
         if not self.console:
-            self.console = sys.stdout # better than crashing
+            self.console = sys.stdout  # better than crashing
         self.installing = False
         self.progress_position = ubiquity.progressposition.ProgressPosition()
         self.progress_val = 0
         self.progress_info = ''
-        self.mainloop = GObject.MainLoop()
+        self.mainloop = GLib.MainLoop()
 
         self.pages = []
         for mod in self.modules:
@@ -71,10 +70,15 @@ class Wizard(BaseFrontend):
         # Is this even needed anymore now that Ubiquity elevates its
         # privileges?
         if os.getuid() != 0:
-            print >>self.console, 'This installer must be run with administrative ' \
-                'privileges, and cannot continue without them.'
+            print('This installer must be run with administrative '
+                  'privileges, and cannot continue without them.',
+                  file=self.console)
             sys.exit(1)
 
+        telemetry.get().set_installer_type('NonInteractive')
+        telemetry.get().set_is_oem(self.oem_config)
+        telemetry.get().add_stage(telemetry.START_INSTALL_STAGE_TAG)
+
         for x in self.pages:
             if issubclass(x.filter_class, Plugin):
                 ui = x.ui
@@ -91,12 +95,12 @@ class Wizard(BaseFrontend):
         self.progress_loop()
 
     def progress_loop(self):
-        """prepare, copy and config the system in the core install process."""
-
+        """Prepare, copy and configure the system."""
         self.start_debconf()
         dbfilter = partman_commit.PartmanCommit(self)
         if dbfilter.run_command(auto_process=True) != 0:
-            print >>self.console, '\nUnable to commit the partition table, exiting.'
+            print('\nUnable to commit the partition table, exiting.',
+                  file=self.console)
             return
 
         self.start_debconf()
@@ -107,7 +111,8 @@ class Wizard(BaseFrontend):
             ret = dbfilter.run_command(auto_process=True)
         if ret == 0:
             self.run_success_cmd()
-            print >>self.console, 'Installation complete.'
+            print('Installation complete.', file=self.console)
+            telemetry.get().done(self.db)
             if self.get_reboot():
                 misc.execute("reboot")
         if ret != 0:
@@ -119,11 +124,10 @@ class Wizard(BaseFrontend):
                                        signal.SIGTERM)):
                 sys.exit(ret)
             elif os.path.exists('/var/lib/ubiquity/install.trace'):
-                tbfile = open('/var/lib/ubiquity/install.trace')
-                realtb = tbfile.read()
-                tbfile.close()
+                with open('/var/lib/ubiquity/install.trace') as tbfile:
+                    realtb = tbfile.read()
                 raise RuntimeError("Install failed with exit code %s\n%s" %
-                                  (ret, realtb))
+                                   (ret, realtb))
 
     def watch_debconf_fd(self, from_debconf, process_input):
         """Event loop interface to debconffilter.
@@ -135,17 +139,17 @@ class Wizard(BaseFrontend):
         from the filtered command and a process_input callback which should
         be called when input events are received."""
 
-        GObject.io_add_watch(from_debconf,
-                             GObject.IO_IN | GObject.IO_ERR | GObject.IO_HUP,
-                             self.watch_debconf_fd_helper, process_input)
+        GLib.io_add_watch(from_debconf,
+                          GLib.IO_IN | GLib.IO_ERR | GLib.IO_HUP,
+                          self.watch_debconf_fd_helper, process_input)
 
-    def watch_debconf_fd_helper (self, source, cb_condition, callback):
+    def watch_debconf_fd_helper(self, source, cb_condition, callback):
         debconf_condition = 0
-        if (cb_condition & GObject.IO_IN) != 0:
+        if (cb_condition & GLib.IO_IN) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_IN
-        if (cb_condition & GObject.IO_ERR) != 0:
+        if (cb_condition & GLib.IO_ERR) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_ERR
-        if (cb_condition & GObject.IO_HUP) != 0:
+        if (cb_condition & GLib.IO_HUP) != 0:
             debconf_condition |= filteredcommand.DEBCONF_IO_HUP
 
         return callback(source, debconf_condition)
@@ -191,7 +195,8 @@ class Wizard(BaseFrontend):
     def debconf_progress_set(self, progress_val):
         """Set the current progress bar's position to progress_val."""
         self.progress_val = progress_val
-        print >>self.console, '%d%%: %s' % (self.progress_val, self.progress_info)
+        print('%d%%: %s' % (self.progress_val, self.progress_info),
+              file=self.console)
         return True
 
     def debconf_progress_step(self, progress_inc):
@@ -201,7 +206,8 @@ class Wizard(BaseFrontend):
     def debconf_progress_info(self, progress_info):
         """Set the current progress bar's message to progress_info."""
         self.progress_info = progress_info
-        print >>self.console, '%d%%: %s' % (self.progress_val, self.progress_info)
+        print('%d%%: %s' % (self.progress_val, self.progress_info),
+              file=self.console)
         return True
 
     def debconf_progress_stop(self):
@@ -220,20 +226,14 @@ class Wizard(BaseFrontend):
 
     def return_to_partitioning(self):
         """Return to partitioning following a commit error."""
-        print >>self.console, '\nCommit failed on partitioning.  Exiting.'
+        print('\nCommit failed on partitioning.  Exiting.', file=self.console)
         sys.exit(1)
 
-    # ubiquity.components.migrationassistant
-
-    # FIXME: Needed by m-a, but is it really necessary?
-    def allow_go_forward(self, allow):
-        pass
-
     # General facilities for components.
 
     def error_dialog(self, title, msg, fatal=True):
         """Display an error message dialog."""
-        print >>self.console, '\n%s: %s' % (title, msg)
+        print('\n%s: %s' % (title, msg), file=self.console)
 
     def question_dialog(self, unused_title, unused_msg, unused_options,
                         use_templates=True):
