@@ -24,8 +24,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-from __future__ import print_function
-
 import os
 import re
 
@@ -413,6 +411,14 @@ class PageGtk(PageBase):
 
         self.controller.allow_go_forward(complete)
 
+    def on_password_toggle_visibility(self, widget, icon_pos, event):
+        from gi.repository import Gtk
+        visibility = self.password.get_visibility()
+        self.password.set_visibility(not visibility)
+        self.verified_password.set_visibility(not visibility)
+        self.password.set_icon_from_icon_name(
+            Gtk.EntryIconPosition.SECONDARY, ('view-conceal-symbolic', 'view-reveal-symbolic')[visibility])
+
     def on_username_changed(self, widget):
         self.username_edited = (widget.get_text() != '')
 
@@ -516,7 +522,9 @@ class PageGtk(PageBase):
 
         self.controller._wizard.set_page_title(self)
 
-    def plugin_set_online_state(self, state):
+    def plugin_set_connectivity_state(self, state):
+        # For AD we need network connectivity but it can be local and not
+        # necessarily internet connectivity
         if not state:
             self.login_directory.set_active(False)
         self.login_directory.set_sensitive(state)
@@ -554,7 +562,7 @@ class PageKde(PageBase):
         self.controller = controller
 
         from PyQt5 import uic
-        from PyQt5.QtGui import QPixmap
+        from PyQt5.QtGui import QPixmap, QIcon
 
         self.plugin_widgets = uic.loadUi(
             '/usr/share/ubiquity/qt/stepUserSetup.ui')
@@ -587,11 +595,14 @@ class PageKde(PageBase):
         self.page.password_error_image.setPixmap(warningIcon)
         self.page.hostname_error_image.setPixmap(warningIcon)
 
+        self.page.show_password.setIcon(QIcon.fromTheme("password-show-off"))
+
         self.clear_errors()
 
         self.page.fullname.textChanged[str].connect(self.on_fullname_changed)
         self.page.username.textChanged[str].connect(self.on_username_changed)
         self.page.hostname.textChanged[str].connect(self.on_hostname_changed)
+        self.page.show_password.toggled.connect(self.on_show_password)
         # self.page.password.textChanged[str].connect(self.on_password_changed)
         # self.page.verified_password.textChanged[str].connect(
         #    self.on_verified_password_changed)
@@ -599,6 +610,16 @@ class PageKde(PageBase):
         self.page.password_debug_warning_label.setVisible(
             'UBIQUITY_DEBUG' in os.environ)
 
+    def on_show_password(self, state):
+        from PyQt5 import QtWidgets
+        from PyQt5.QtGui import QIcon
+
+        modes = (QtWidgets.QLineEdit.Password, QtWidgets.QLineEdit.Normal)
+        icons = ("password-show-off", "password-show-on")
+        self.page.password.setEchoMode(modes[state])
+        self.page.verified_password.setEchoMode(modes[state])
+        self.page.show_password.setIcon(QIcon.fromTheme(icons[state]))
+
     def on_fullname_changed(self):
         # If the user did not manually enter a username create one for him.
         if not self.username_edited:
