@@ -24,7 +24,7 @@ from ubiquity import plugin
 
 NAME = 'wireless'
 # after prepare for default install, but language for oem install
-AFTER = 'language'
+AFTER = 'console_setup'
 WEIGHT = 12
 
 
@@ -62,6 +62,7 @@ class PageGtk(WirelessPageBase):
         # as importing it as the side effect of registering
         # NetworkManagerWidget which we DO use in the Wireless step UI.
         from ubiquity.frontend.gtk_components import nmwidgets
+        assert nmwidgets  # silence, pyflakes
 
         if self.is_automatic:
             self.page = None
@@ -104,6 +105,8 @@ class PageGtk(WirelessPageBase):
             frontend.next.set_label(self.connect_text)
         if not self.back_normal:
             frontend.back.set_label(self.stop_text)
+        frontend.status_label.set_text(self.controller.get_string(
+            'ubiquity/text/connecting_label', lang))
 
     def selection_changed(self, unused):
         from ubiquity import nm
@@ -131,9 +134,9 @@ class PageGtk(WirelessPageBase):
                 self.nmwidget.select_usable_row()
             self.state_changed(None, self.state)
         else:
-            frontend.connecting_spinner.hide()
-            frontend.connecting_spinner.stop()
-            frontend.connecting_label.hide()
+            frontend.status_spinner.hide()
+            frontend.status_spinner.stop()
+            frontend.status_label.hide()
             frontend.translate_widget(frontend.next)
             self.next_normal = True
             self.controller.allow_go_forward(True)
@@ -144,9 +147,9 @@ class PageGtk(WirelessPageBase):
             self.nmwidget.disconnect_from_ap()
             return True
         else:
-            frontend.connecting_spinner.hide()
-            frontend.connecting_spinner.stop()
-            frontend.connecting_label.hide()
+            frontend.status_spinner.hide()
+            frontend.status_spinner.stop()
+            frontend.status_label.hide()
             self.no_wireless.set_active(True)
             return False
 
@@ -156,9 +159,9 @@ class PageGtk(WirelessPageBase):
             self.nmwidget.connect_to_ap()
             return True
         else:
-            frontend.connecting_spinner.hide()
-            frontend.connecting_spinner.stop()
-            frontend.connecting_label.hide()
+            frontend.status_spinner.hide()
+            frontend.status_spinner.stop()
+            frontend.status_label.hide()
             return False
 
     def state_changed(self, unused, state):
@@ -169,17 +172,17 @@ class PageGtk(WirelessPageBase):
         if not self.use_wireless.get_active():
             return
         if state != nm.NM_STATE_CONNECTING:
-            frontend.connecting_spinner.hide()
-            frontend.connecting_spinner.stop()
-            frontend.connecting_label.hide()
+            frontend.status_spinner.hide()
+            frontend.status_spinner.stop()
+            frontend.status_label.hide()
 
             frontend.translate_widget(frontend.back)
             self.back_normal = True
             frontend.back.set_sensitive(True)
         else:
-            frontend.connecting_spinner.show()
-            frontend.connecting_spinner.start()
-            frontend.connecting_label.show()
+            frontend.status_spinner.show()
+            frontend.status_spinner.start()
+            frontend.status_label.show()
 
             self.next_normal = True
 
@@ -212,14 +215,13 @@ class PageKde(WirelessPageBase):
         self.plugin_widgets = self.page
 
     def _setup_page(self):
-        from PyQt4 import uic, QtGui
+        from PyQt5 import uic, QtWidgets
         from ubiquity.frontend.kde_components import nmwidgets
         self.nmwidget = nmwidgets.NetworkManagerWidget()
         self.nmwidget.state_changed.connect(self._update_ui)
 
         self.page = uic.loadUi('/usr/share/ubiquity/qt/stepWireless.ui')
-        layout = QtGui.QHBoxLayout(self.page.nmwidget_container)
-        layout.setMargin(0)
+        layout = QtWidgets.QHBoxLayout(self.page.nmwidget_container)
         layout.addWidget(self.nmwidget)
 
         self.page.use_wireless.toggled.connect(self._update_ui)
